@@ -44,4 +44,4 @@ class Base:
             if conn:
                 conn.close()
                 self.t_1 = datetime.now()
-        return result["response_data"]
+        return result
